@@ -10,9 +10,7 @@
 #include "public/include/XMP_Version.h"
 #include "XMPCore/source/XMPCore_Impl.hpp"
 #include "XMPCore/source/XMPMeta.hpp"	// *** For use of GetNamespacePrefix in FindSchemaNode.
-
 #include "source/UnicodeInlines.incl_cpp"
-
 #include <algorithm>
 
 using namespace std;
@@ -56,6 +54,8 @@ XMP_NamespaceTable * sRegisteredNamespaces = 0;
 
 XMP_AliasMap * sRegisteredAliasMap = 0;
 
+XMP_ReadWriteLock * sDefaultNamespacePrefixMapLock = 0;
+
 void *              voidVoidPtr    = 0;	// Used to backfill null output parameters.
 XMP_StringPtr		voidStringPtr  = 0;
 XMP_StringLen		voidStringLen  = 0;
@@ -68,6 +68,60 @@ double				voidDouble     = 0.0;
 XMP_DateTime		voidDateTime;
 WXMP_Result 		void_wResult;
 
+	#if ENABLE_CPP_DOM_MODEL
+		XMP_Bool         sUseNewCoreAPIs = false;
+	#endif
+
+	#if ! XMP_StaticBuild
+
+		#undef malloc
+		#undef free
+		typedef void * (*XMP_AllocateProc) (size_t size);
+
+		typedef void(*XMP_DeleteProc)   (void * ptr);
+
+		XMP_AllocateProc sXMP_MemAlloc = malloc;
+		XMP_DeleteProc   sXMP_MemFree  = free;
+		#define malloc(size) (*sXMP_MemAlloc) ( size )
+		#define free(addr)   (*sXMP_MemFree) ( addr )
+		
+		void * operator new ( size_t len ) throw ( std::bad_alloc )
+		{
+			void * mem = (*sXMP_MemAlloc) ( len );
+			if ( (mem == 0) && (len != 0) ) throw std::bad_alloc();
+			return mem;
+		}
+
+        void * operator new( std::size_t len, const std::nothrow_t & nothrow ) throw () {
+            void * mem = (*sXMP_MemAlloc) ( len );
+            return mem;
+        }
+		
+		void * operator new[] ( size_t len ) throw ( std::bad_alloc )
+		{
+			void * mem = (*sXMP_MemAlloc) ( len );
+			if ( (mem == 0) && (len != 0) ) throw std::bad_alloc();
+			return mem;
+		}
+		
+		void operator delete ( void * ptr ) throw()
+		{
+			if ( ptr != 0 ) (*sXMP_MemFree) ( ptr );
+		}
+		
+		void operator delete ( void * ptr, const std::nothrow_t & nothrow ) throw ()
+		{
+			return operator delete( ptr );
+		}
+		
+		void operator delete[] ( void * ptr ) throw()
+		{
+			if ( ptr != 0 ) (*sXMP_MemFree) ( ptr );
+		}
+	
+#endif
+
+
 // =================================================================================================
 // Local Utilities
 // ===============
@@ -212,7 +266,7 @@ FindIndexedItem ( XMP_Node * arrayNode, const XMP_VarString & indexStep, bool cr
 // The value portion is a string quoted by ''' or '"'. The value may contain any character including
 // a doubled quoting character. The value may be empty.
 
-static void
+void
 SplitNameAndValue ( const XMP_VarString & selStep, XMP_VarString * nameStr, XMP_VarString * valueStr )
 {
 	XMP_StringPtr partBegin = selStep.c_str();
@@ -263,7 +317,7 @@ SplitNameAndValue ( const XMP_VarString & selStep, XMP_VarString * nameStr, XMP_
 static XMP_Index
 LookupQualSelector ( XMP_Node * arrayNode, const XMP_VarString & qualName, XMP_VarString & qualValue )
 {
-	XMP_Index index;
+	size_t index;
 		
 	if ( qualName == "xml:lang" ) {
 	
@@ -273,7 +327,7 @@ LookupQualSelector ( XMP_Node * arrayNode, const XMP_VarString & qualName, XMP_V
 	
 	} else {
 
-		XMP_Index itemLim;
+		size_t itemLim;
 		for ( index = 0, itemLim = arrayNode->children.size(); index != itemLim; ++index ) {
 
 			const XMP_Node * currItem = arrayNode->children[index];
@@ -293,7 +347,7 @@ LookupQualSelector ( XMP_Node * arrayNode, const XMP_VarString & qualName, XMP_V
 
 	}
 	
-	return index;
+	return static_cast<XMP_Index>( index );
 	
 }	// LookupQualSelector
 
@@ -348,7 +402,7 @@ FollowXPathStep	( XMP_Node *	   parentNode,
 		if ( stepKind == kXMP_ArrayIndexStep ) {
 			index = FindIndexedItem ( parentNode, nextStep.step, createNodes );
 		} else if ( stepKind == kXMP_ArrayLastStep ) {
-			index = parentNode->children.size() - 1;
+			index = static_cast<XMP_Index>( parentNode->children.size() - 1 );
 		} else if ( stepKind == kXMP_FieldSelectorStep ) {
 			XMP_VarString fieldName, fieldValue;
 			SplitNameAndValue ( nextStep.step, &fieldName, &fieldValue );
@@ -588,7 +642,7 @@ ExpandXPath	( XMP_StringPtr			schemaNS,
 	XMP_Assert ( (schemaNS != 0) && (propPath != 0) && (*propPath != 0) && (expandedXPath != 0) );
 	
 	XMP_StringPtr	stepBegin, stepEnd;
-	XMP_StringPtr	qualName, nameEnd;
+	XMP_StringPtr	qualName = 0 , nameEnd = 0;
 	XMP_VarString	currStep;
 		
 	qualName = nameEnd = NULL;
@@ -749,7 +803,9 @@ XMP_Node *
 FindSchemaNode	( XMP_Node *		xmpTree,
 				  XMP_StringPtr		nsURI,
 				  bool				createNodes,
-				  XMP_NodePtrPos *	ptrPos /* = 0 */ )
+				  XMP_NodePtrPos *	ptrPos /* = 0 */,
+				  PrefixSearchFnPtr prefixSearchFnPtr/* = NULL*/,
+				  void * privateData/* = NULL*/ )
 {
 	XMP_Node * schemaNode = 0;
 	
@@ -773,9 +829,20 @@ FindSchemaNode	( XMP_Node *		xmpTree,
 			XMP_StringPtr prefixPtr;
 			XMP_StringLen prefixLen;
 #if XMP_DebugBuild
-			bool found =
+			bool found;
 #endif
-                          XMPMeta::GetNamespacePrefix ( nsURI, &prefixPtr, &prefixLen );	// *** Use map directly?
+			if (prefixSearchFnPtr && privateData) {
+#if XMP_DebugBuild
+				found =
+#endif
+					prefixSearchFnPtr ( privateData, nsURI, &prefixPtr, &prefixLen );
+			}
+			else {
+#if XMP_DebugBuild
+				found =
+#endif
+					XMPMeta::GetNamespacePrefix ( nsURI, &prefixPtr, &prefixLen );	// *** Use map directly?
+			}
 			XMP_Assert ( found );
 			schemaNode->value.assign ( prefixPtr, prefixLen );
 		} catch (...) {	// Don't leak schemaNode in case of an exception before adding it to the children vector.
@@ -923,7 +990,7 @@ FindQualifierNode	( XMP_Node *		parent,
 XMP_Index
 LookupFieldSelector ( const XMP_Node * arrayNode, XMP_StringPtr fieldName, XMP_StringPtr fieldValue )
 {
-	XMP_Index index, itemLim;
+	size_t index, itemLim;
 	
 	for ( index = 0, itemLim = arrayNode->children.size(); index != itemLim; ++index ) {
 
@@ -946,7 +1013,7 @@ LookupFieldSelector ( const XMP_Node * arrayNode, XMP_StringPtr fieldName, XMP_S
 	}
 	
 	if ( index == itemLim ) index = -1;
-	return index;
+	return static_cast<XMP_Index>( index );
 	
 }	// LookupFieldSelector
 
@@ -963,8 +1030,8 @@ LookupLangItem ( const XMP_Node * arrayNode, XMP_VarString & lang )
 		XMP_Throw ( "Language item must be used on array", kXMPErr_BadXPath );
 	}
 
-	XMP_Index index   = 0;
-	XMP_Index itemLim = arrayNode->children.size();
+	size_t index   = 0;
+	size_t itemLim = arrayNode->children.size();
 	
 	for ( ; index != itemLim; ++index ) {
 		const XMP_Node * currItem = arrayNode->children[index];
@@ -974,7 +1041,7 @@ LookupLangItem ( const XMP_Node * arrayNode, XMP_VarString & lang )
 	}
 	
 	if ( index == itemLim ) index = -1;
-	return index;
+	return static_cast<XMP_Index>( index );
 	
 }	// LookupLangItem
 
