@@ -24,6 +24,8 @@
 
 #include "third-party/zuid/interfaces/MD5.h"
 
+#include <algorithm>
+
 using namespace std;
 
 // =================================================================================================
@@ -271,7 +273,6 @@ static void CacheExtendedXMP ( ExtendedXMPInfo * extXMP, XMP_Uns8 * buffer, size
 void JPEG_MetaHandler::CacheFileData()
 {
 	XMP_IO* fileRef = this->parent->ioRef;
-	XMP_PacketInfo & packetInfo = this->packetInfo;
 
 	static const size_t kBufferSize = 64*1024;	// Enough for maximum segment contents.
 	XMP_Uns8 buffer [kBufferSize];
@@ -450,8 +451,6 @@ void JPEG_MetaHandler::CacheFileData()
 // temporary read-only parse of the Exif APP1 contents, determine the highest used offset, trim the
 // padding if all zero bytes.
 
-static const char * IFDNames[] = { "Primary", "TNail", "Exif", "GPS", "Interop", };
-
 static void TrimFullExifAPP1 ( std::string * exifContents )
 {
 	TIFF_MemoryReader tempMgr;
@@ -482,8 +481,8 @@ static void TrimFullExifAPP1 ( std::string * exifContents )
 		TIFF_MemoryReader::TagInfoMap::const_iterator mapEnd = tagMap.end();
 
 		for ( ; mapPos != mapEnd; ++mapPos ) {
-			const TIFF_MemoryReader::TagInfo & tagInfo = mapPos->second;
-			XMP_Uns32 tagEnd = tempMgr.GetValueOffset ( ifd, tagInfo.id ) + tagInfo.dataLen;
+			const TIFF_MemoryReader::TagInfo & value = mapPos->second;
+			XMP_Uns32 tagEnd = tempMgr.GetValueOffset ( ifd, value.id ) + value.dataLen;
 			if ( tagEnd > padOffset ) padOffset = tagEnd;
 		}
 
@@ -651,8 +650,7 @@ void JPEG_MetaHandler::ProcessXMP()
 	// Process the legacy metadata.
 
 	if ( haveIPTC && (! haveXMP) && (iptcDigestState == kDigestMatches) ) iptcDigestState = kDigestMissing;
-	bool parseIPTC = (iptcDigestState != kDigestMatches) || (! readOnly);
-	if ( parseIPTC ) iptc.ParseMemoryDataSets ( iptcInfo.dataPtr, iptcInfo.dataLen );
+	if (iptcInfo.dataLen) iptc.ParseMemoryDataSets ( iptcInfo.dataPtr, iptcInfo.dataLen );
 	ImportPhotoData ( exif, iptc, psir, iptcDigestState, &this->xmpObj, options );
 
 	this->containsXMP = true;	// Assume we had something for the XMP.
@@ -665,6 +663,7 @@ void JPEG_MetaHandler::ProcessXMP()
 
 void JPEG_MetaHandler::UpdateFile ( bool doSafeUpdate )
 {
+	IgnoreParam(doSafeUpdate);
 	XMP_Assert ( ! doSafeUpdate );	// This should only be called for "unsafe" updates.
 
 	XMP_Int64 oldPacketOffset = this->packetInfo.offset;
@@ -961,7 +960,7 @@ void JPEG_MetaHandler::WriteTempFile ( XMP_IO* tempRef )
 			}
 			
 			if ( copySegment && (signatureLen == kExtXMPSignatureLength) &&
-				 CheckBytes ( &buffer[0], kExtXMPSignatureString, kExtXMPPrefixLength ) ) {
+				CheckBytes ( &buffer[0], kExtXMPSignatureString, kExtXMPSignatureLength ) ) {
 				copySegment = false;
 			}
 			
