@@ -14,11 +14,14 @@
 
 #include "XMPFiles/source/XMPFiles_Impl.hpp"
 #include "XMPFiles/source/FormatSupport/Reconcile_Impl.hpp"
+#include "source/UnicodeConversions.hpp"
 #include "source/XMPFiles_IO.hpp"
 #include "source/XIO.hpp"
 
 #include "XMPFiles/source/FileHandlers/MP3_Handler.hpp"
 
+#include <sstream>
+
 // =================================================================================================
 /// \file MP3_Handler.cpp
 /// \brief MP3 handler class.
@@ -83,7 +86,7 @@ bool MP3_CheckFormat ( XMP_FileFormat format,
 					  XMP_IO*    file,
 					  XMPFiles *     parent )
 {
-	IgnoreParam(filePath); IgnoreParam(parent);	//supress warnings
+	IgnoreParam(format); IgnoreParam(filePath); IgnoreParam(parent);	//suppress warnings
 	XMP_Assert ( format == kXMP_MP3File );		//standard assert
 
 	if ( file->Length() < 10 ) return false;
@@ -164,7 +167,7 @@ void MP3_MetaHandler::CacheFileData()
 	this->containsXMP = false;		//assume no XMP for now
 
 	XMP_IO* file = this->parent->ioRef;
-	XMP_PacketInfo &packetInfo = this->packetInfo;
+	/* XMP_PacketInfo &packetInfo = this->packetInfo; */
 
 	file->Rewind();
 
@@ -187,7 +190,7 @@ void MP3_MetaHandler::CacheFileData()
 	} else {
 
 		this->extHeaderSize = synchToInt32( XIO::ReadInt32_BE( file));
-		XMP_Uns8 extHeaderNumFlagBytes = XIO::ReadUns8( file );
+		/*XMP_Uns8 extHeaderNumFlagBytes =*/ XIO::ReadUns8( file );
 
 		// v2.3 doesn't include the size, while v2.4 does
 		if ( this->majorVersion < 4 ) this->extHeaderSize += 4;
@@ -204,7 +207,10 @@ void MP3_MetaHandler::CacheFileData()
 	// read frames
 	
 	XMP_Uns32 xmpID = XMP_V23_ID;
-	if ( this->majorVersion == 2 ) xmpID = XMP_V22_ID;
+	if ( this->majorVersion == 2 )
+	{
+		xmpID = XMP_V22_ID;
+	}
 
 	while ( file->Offset() < this->oldTagSize ) {
 
@@ -442,10 +448,9 @@ void MP3_MetaHandler::ProcessXMP()
         if ( xmpObj.GetProperty_Date ( kXMP_NS_XMP, "CreateDate", &oldDateTime, 0 ) )
         {
 
-            haveNewDateTime = haveNewDateTime && 
-                                                        ( (newDateTime.year != oldDateTime.year) ||
-                                                            ( (newDateTime.month != 0 ) && ( (newDateTime.day != oldDateTime.day) || (newDateTime.month != oldDateTime.month) ) ) ||
-                                                            ( newDateTime.hasTime && ( (newDateTime.hour != oldDateTime.hour) || (newDateTime.minute != oldDateTime.minute) ) ) );
+            haveNewDateTime = haveNewDateTime && ( (newDateTime.year != oldDateTime.year) || ( (newDateTime.month != 0 )
+							  && ( (newDateTime.day != oldDateTime.day) || (newDateTime.month != oldDateTime.month) ) )
+							  || ( newDateTime.hasTime && ( (newDateTime.hour != oldDateTime.hour) || (newDateTime.minute != oldDateTime.minute) ) ) );
         }
             // NOTE: no further validation nessesary the function "SetProperty_Date" will care about validating date and time
             // any exception will be caught and block import
@@ -709,7 +714,7 @@ void MP3_MetaHandler::UpdateFile ( bool doSafeUpdate )
 	}
 
 	// check end of file for ID3v1 tag
-	XMP_Int64 possibleTruncationPoint = file->Seek ( -128, kXMP_SeekFromEnd );
+	/* XMP_Int64 possibleTruncationPoint = */ file->Seek ( -128, kXMP_SeekFromEnd );
 	bool alreadyHasID3v1 = (XIO::ReadInt32_BE( file ) & 0xFFFFFF00) == 0x54414700; // "TAG"
 	if ( ! alreadyHasID3v1 ) file->Seek ( 128, kXMP_SeekFromEnd );	// Seek will extend the file.
 	id3v1Tag.write( file, &this->xmpObj );
@@ -727,3 +732,4 @@ void MP3_MetaHandler::WriteTempFile ( XMP_IO* tempRef )
 	IgnoreParam(tempRef);
 	XMP_Throw ( "MP3_MetaHandler::WriteTempFile: Not supported", kXMPErr_Unimplemented );
 }	// MP3_MetaHandler::WriteTempFile
+
