@@ -145,7 +145,7 @@ bool ASF_Support::ReadHeaderObject ( XMP_IO* fileRef, ObjectState& inOutObjectSt
 		pos += bufferSize;
 
 		// read contained header objects
-		XMP_Uns32 numberOfHeaders = GetUns32LE ( &buffer[24] );
+		/*XMP_Uns32 numberOfHeaders = GetUns32LE ( &buffer[24] );*/
 		ASF_ObjectBase objectBase;
 
 		while ( read < newObject.len ) {
@@ -188,7 +188,7 @@ bool ASF_Support::ReadHeaderObject ( XMP_IO* fileRef, ObjectState& inOutObjectSt
 				XMP_Uns16 authorLen = GetUns16LE ( &buffer[26] );
 				XMP_Uns16 copyrightLen = GetUns16LE ( &buffer[28] );
 				XMP_Uns16 descriptionLen = GetUns16LE ( &buffer[30] );
-				XMP_Uns16 ratingLen = GetUns16LE ( &buffer[32] );
+				/*XMP_Uns16 ratingLen = GetUns16LE ( &buffer[32] );*/
 
 				XMP_Uns16 fieldPos = 34;
 
@@ -316,7 +316,7 @@ bool ASF_Support::WriteHeaderObject ( XMP_IO* sourceRef, XMP_IO* destRef, const
 		pos += bufferSize;
 
 		// read contained header objects
-		XMP_Uns32 numberOfHeaders = GetUns32LE ( &buffer[24] );
+		/*XMP_Uns32 numberOfHeaders = GetUns32LE ( &buffer[24] );*/
 		ASF_ObjectBase objectBase;
 
 		// prepare new header in memory
@@ -730,7 +730,7 @@ bool ASF_Support::UpdateFileSize ( XMP_IO* fileRef )
 
 // =============================================================================================
 
-bool ASF_Support::ReadHeaderExtensionObject ( XMP_IO* fileRef, ObjectState& inOutObjectState, const XMP_Uns64& _pos, const ASF_ObjectBase& _objectBase )
+bool ASF_Support::ReadHeaderExtensionObject ( XMP_IO* fileRef, ObjectState& /*inOutObjectState*/, const XMP_Uns64& _pos, const ASF_ObjectBase& _objectBase )
 {
 	if ( ! IsEqualGUID ( ASF_Header_Extension_Object, _objectBase.guid) || (! legacyManager ) ) return false;
 
